4.37. umbra.reporter — Umbra 1.0.9 documentation

# 4.37. umbra.reporter

reporter.py

Platform:
  Windows, Linux, Mac Os X.
Description:
  Defines the `Reporter` class and various others exceptions handling related objects.

Others:

## 4.37.1. Module Attributes

`umbra.reporter.` `LOGGER`

`umbra.reporter.` `UI_FILE`

## 4.37.2. Functions

`umbra.reporter.` `baseExceptionHandler`(*args)

  Provides a base exception handler.

  Parameters: | *args (*) – Arguments.
  Returns: | Definition success.
  Return type: | bool

`umbra.reporter.` `systemExitExceptionHandler`(*args)

  Provides a system exit exception handler.

  Parameters: | *args (*) – Arguments.
  Returns: | Definition success.
  Return type: | bool

`umbra.reporter.` `criticalExceptionHandler`(object)

  Marks an object that would system exit in case of critical exception.

  Parameters: | object (object) – Object to decorate.
  Returns: | Object.
  Return type: | object

`umbra.reporter.` `installExceptionReporter`(report=True)

  Installs the exceptions reporter.

  Parameters: | report (bool) – Report to Crittercism.
  Returns: | Reporter instance.
  Return type: | Reporter

`umbra.reporter.` `uninstallExceptionReporter`()

  Uninstalls the exceptions reporter.

  Returns: | Definition success.
  Return type: | bool

`umbra.reporter.` `enableExceptionReporter`()

  Enables the exceptions reporter.

  Returns: | Definition success.
  Return type: | bool

`umbra.reporter.` `disableExceptionReporter`()

  Disables the exceptions reporter.

  Returns: | Definition success.
  Return type: | bool

## 4.37.3. Classes

class `umbra.reporter.` `Reporter`(parent=None, report=True, enabled=True, *args, **kwargs)

  Bases: `foundations.ui.common.QWidget`

  Defines an exception reporting Widget.

  Initializes the class.

  Parameters: | parent (QObject) – Object parent. report (bool) – Report to Crittercism. enabled (bool) – Is reporter enabled. *args (*) – Arguments. **kwargs (**) – Keywords arguments.

  `report`

    Property for self.__report attribute.

    Returns: | self.__report.
    Return type: | bool

  `enabled`

    Property for self.__enabled attribute.

    Returns: | self.__enabled.
    Return type: | bool

  `show`()

    Reimplements the `QWidget.show()` method.

  `handleException`(*args)

    Handles given exception.

    Parameters: | *args (*) – Arguments.

  `formatHtmlException`(*args)

    Formats given exception as an html text.

    Parameters: | *args (*) – Arguments.
    Returns: | Exception html text.
    Return type: | unicode

  `formatTextException`(*args)

    Formats given exception as a text.

    Parameters: | *args (*) – Arguments.
    Returns: | Exception text.
    Return type: | unicode

  `reportExceptionToCrittercism`(*args)

    Reports given exception to Crittercism.

    Parameters: | *args (*) – Arguments.
    Returns: | Method success.
    Return type: | bool